@@ -43,7 +43,7 @@ class BaseController extends ActionController
     /**
      * @var RegionRepository
      */
-    private $regionRepository;
+    protected $regionRepository;
 
     /**
      * @param RegionRepository $regionRepository
@@ -56,7 +56,7 @@ class BaseController extends ActionController
     /**
      * @var OrtRepository
      */
-    private $ortRepository;
+    protected $ortRepository;
 
     /**
      * @param OrtRepository $ortRepository
@@ -69,7 +69,7 @@ class BaseController extends ActionController
     /**
      * @var StadtteilRepository
      */
-    private $stadtteilRepository;
+    protected $stadtteilRepository;
 
     /**
      * @param StadtteilRepository $stadtteilRepository
@@ -82,7 +82,7 @@ class BaseController extends ActionController
     /**
      * @var ImmobilieRepository
      */
-    private $immobilieRepository;
+    protected $immobilieRepository;
 
     /**
      * @param ImmobilieRepository $immobilieRepository
@@ -95,7 +95,7 @@ class BaseController extends ActionController
     /**
      * @var ObjektartRepository
      */
-    private $objektartRepository;
+    protected $objektartRepository;
 
     /**
      * @param ObjektartRepository $objektartRepository
@@ -108,7 +108,7 @@ class BaseController extends ActionController
     /**
      * @var ObjektarttypRepository
      */
-    private $objektarttypRepository;
+    protected $objektarttypRepository;
 
     /**
      * @param ObjektarttypRepository $objektarttypRepository
@@ -121,7 +121,7 @@ class BaseController extends ActionController
     /**
      * @var HeizungsartRepository
      */
-    private $heizungsartRepository;
+    protected $heizungsartRepository;
 
     /**
      * @param HeizungsartRepository $heizungsartRepository
@@ -134,7 +134,7 @@ class BaseController extends ActionController
     /**
      * @var SessionHandler
      */
-    private $sessionHandler;
+    protected $sessionHandler;
 
     /**
      * @param SessionHandler $sessionHandler
@@ -147,7 +147,7 @@ class BaseController extends ActionController
     /**
      * @var Services
      */
-    private $sgEstateCoreServices;
+    protected $sgEstateCoreServices;
 
     /**
      * @param Services $services
@@ -186,17 +186,17 @@ class BaseController extends ActionController
     /**
      * @var Filter
      */
-    private $filter;
+    protected $filter;
 
     /**
      * @var FrontendInterface
      */
-    private $cache;
+    protected $cache;
 
     /**
      * @var bool
      */
-    private $noSearchParameters = false;
+    protected $noSearchParameters = false;
 
     public function __construct(FrontendInterface $cache)
     {
@@ -218,12 +218,11 @@ class BaseController extends ActionController
      *********************************************/
 
     /**
-     * Action for Standard Searchbox
+     * Action for Standard Search
      */
     public function searchAction()
     {
 
-        // this fix multilanguge sites
         $shows = '0';
         if($this->settings['show']) {
             if (is_array($this->settings['show']))
@@ -233,18 +232,120 @@ class BaseController extends ActionController
             if (is_int($this->settings['show']))
                 $shows = (string)$this->settings['show'];
         }
-        //$cacheIdentifier = 'search_' . $this->settings['search']['layout'] . '_' . $shows . '_' . $this->settings['search']['layout'] . '_L' . $this->getLanguageUid();
-        ////$cacheIdentifier = strtolower($this->settings['search']['layout']).'_search_' . $this->filter->getCacheIdentifier();
+        $cacheIdentifier = 'search_' . $this->settings['search']['layout'] . '_' . $shows . '_' . $this->settings['search']['layout'] . '_L' . $this->getLanguageUid();
 
-        //if (($entry = $this->cache->get($cacheIdentifier)) === false) {
-            $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
-            foreach ($kindOfObjectUids as $kindOfObjectUid) {
-                $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
-                if ($kindOfObject instanceof Objektart) {
-                    $this->filter->addObjektart($kindOfObject);
+        if (($entry = $this->cache->get($cacheIdentifier)) === false) {
+            if ($this->settings['preset']['search']['filterData'] != 0) {
+                $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
+                foreach ($kindOfObjectUids as $kindOfObjectUid) {
+                    $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
+                    if ($kindOfObject instanceof Objektart) {
+                        $this->filter->addObjektart($kindOfObject);
+                    }
                 }
+
+                if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+                    $arrayOfImportIds = explode(',', $this->settings['importids']);
+                    if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
+                        $this->filter->setImportIds($arrayOfImportIds);
+                    } else {
+                        $this->filter->setImportIds([]);
+                    }
+                } else {
+                    $arrayOfImportIds = null;
+                }
+
+                if ($this->settings['preset']['search']['useSlider'] == 1) {
+                    // BEGIN: Assign Values for Slider-Configuration to View
+                    $this->view->assign('sizeSliderData', $this->getSizeSliderData());
+                    $this->view->assign('roomSliderData', $this->getRoomSliderData());
+                    $this->view->assign('amountSliderData', $this->getAmountSliderData());
+                    // END: Assign Values for Slider-Configuration to View
+                }
+
+                $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
+                $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
+                $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
+                $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+                $this->view->assign('filter', $this->filter);
+                $this->view->assign('cities', $this->ortRepository->findAll());
+
+
+                $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
+                $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
+
+                if ($this->settings['preset']['search']['simpleRealtyData'] == 1){
+                    $returnArray = $this->immobilieRepository->findAllWithFilterData();
+                    $realtiesModifited = $returnArray['realties'];
+                    $this->view->assign('places', $returnArray['cities']);
+                }
+                else {
+                    $realties = $this->immobilieRepository->findAllWithFilter($this->filter);
+                    $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
+
+                    $this->view->assign('realties', $realties);
+                    $realtiesModifited = array();
+                    foreach ($realties as $k => $v) {
+                        $realtiesModifited[$k]['anzahlZimmer'] = $v->getAnzahlZimmer();
+                        $realtiesModifited[$k]['vermietbareFlaeche'] = $v->getVermietbareFlaeche();
+                        $realtiesModifited[$k]['kaltmiete'] = $v->getKaltmiete();
+                        $realtiesModifited[$k]['objektOrt'] = is_null($v->getObjektOrt()) ? '' : 'region-' . $v->getObjektOrt()->getUid();
+                        $realtiesModifited[$k]['objektStadtteil'] = is_null($v->getObjektStadtteil()) ? '' : 'district-' . $v->getObjektStadtteil()->getUid();
+                    }
+                }
+                $this->view->assign('realtiesModifited', $realtiesModifited);
             }
 
+            $entry = $this->view->render();
+
+            $tags = ['search'];
+            $lifetime = $this->settings['defaultCacheLifetime'];
+
+            // Save value in cache
+            $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
+        }
+        return $entry;
+    }
+
+    /**
+     * Action for Standard Searchbox
+     */
+    public function searchboxAction()
+    {
+        $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
+        foreach ($kindOfObjectUids as $kindOfObjectUid) {
+            $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
+            if ($kindOfObject instanceof Objektart) {
+                $this->filter->addObjektart($kindOfObject);
+            }
+        }
+        if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+            $arrayOfImportIds = explode(',', $this->settings['importids']);
+            if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
+                $this->filter->setImportIds($arrayOfImportIds);
+            } else {
+                $this->filter->setImportIds([]);
+            }
+        } else {
+            $arrayOfImportIds = null;
+        }
+        $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
+        $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
+        $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
+        $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+        $this->view->assign('filter', $this->filter);
+        $this->view->assign('cities', $this->ortRepository->findAll());
+        return $this->view->render();
+    }
+
+    /**
+     * Action for Standard List View
+     */
+    public function listAction()
+    {
+            /**
+             * @var $filter Filter
+             */
             if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
                 $arrayOfImportIds = explode(',', $this->settings['importids']);
                 if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
@@ -256,136 +357,95 @@ class BaseController extends ActionController
                 $arrayOfImportIds = null;
             }
 
-            if ($this->settings['preset']['search']['useSlider'] == 1) {
-                // BEGIN: Assign Values for Slider-Configuration to View
-                $this->view->assign('sizeSliderData', $this->getSizeSliderData());
-                $this->view->assign('roomSliderData', $this->getRoomSliderData());
-                $this->view->assign('amountSliderData', $this->getAmountSliderData());
-                // END: Assign Values for Slider-Configuration to View
-            }
+            if (isset($this->settings['list']['layout']) && $this->settings['list']['layout'] == 'LiveSearch') {
+                $filter = $this->objectManager->get('SG\SgEstateCore\Domain\Model\Filter');
 
-            $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
-            $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
-            $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
-            $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
-            $this->view->assign('filter', $this->filter);
-            $this->view->assign('cities', $this->ortRepository->findAll());
-
-
-            $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
-            $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
-            $realties = $this->immobilieRepository->findAllWithFilter($this->filter);
-            $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
-
-            $this->view->assign('realties', $realties);
-            $realtiesModifited = array();
-            foreach($realties as $k=>$v) {
-                $realtiesModifited[$k]['anzahlZimmer'] = $v->getAnzahlZimmer();
-                $realtiesModifited[$k]['vermietbareFlaeche'] = $v->getVermietbareFlaeche();
-                $realtiesModifited[$k]['kaltmiete'] = $v->getKaltmiete();
-                $realtiesModifited[$k]['objektOrt'] = 'region-' . $v->getObjektOrt()->getUid();
-                $realtiesModifited[$k]['objektStadtteil'] = 'district-' . $v->getObjektStadtteil()->getUid();
-            }
-            $this->view->assign('realtiesModifited', $realtiesModifited);
-
-            $entry = $this->view->render();
-
-            $tags = ['search'];
-            $lifetime = $this->settings['defaultCacheLifetime'];
-
-            // Save value in cache
-            //$this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
-        //}
-        return $entry;
-    }
-
-    /**
-     * Action for Standard List View
-     */
-    public function listAction()
-    {
-        /**
-         * @var $filter Filter
-         */
-        if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
-            $arrayOfImportIds = explode(',', $this->settings['importids']);
-            if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
-                $this->filter->setImportIds($arrayOfImportIds);
-            } else {
-                $this->filter->setImportIds([]);
-            }
-        } else {
-            $arrayOfImportIds = null;
-        }
-
-        if (isset($this->settings['list']['layout']) && $this->settings['list']['layout'] == 'LiveSearch') {
-            $filter = $this->objectManager->get('SG\SgEstateCore\Domain\Model\Filter');
-
-            // add city to this filte
-            $ort = $this->filter->getOrt();
-            if ($ort instanceof Ort) {
-                $filter->addOrt($ort);
-            }
-            if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
-                $filter->setImportIds($this->filter->getImportIds());
-            }
-
-            $filterToUse = $filter;
-            $cacheIdentifier = 'list_' . $this->filter->getCacheIdentifier() . '_L' . $this->getLanguageUid();
-        } else {
-            $filterToUse = $this->filter;
-            $cacheIdentifier = 'list_' . $filterToUse->getCacheIdentifier() . '_L' . $this->getLanguageUid();
-        }
-
-        if ($this->noSearchParameters && $this->settings['list']['noParametersNoResults'] !== '0') {
-            if (($entry = $this->cache->get('sg_estate_base_empty_result' . '_L' . $this->getLanguageUid())) === false) {
-                $this->view->assign('realties', []);
-                $this->view->assign('aggregatedFilterData', json_encode([]));
-                $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
-
-                $this->view->assign('presets', $this->generateFilterPresetsFromResult([]));
-
-                $entry = $this->view->render();
-
-                $tags = ['listing', 'searchresult'];
-                $lifetime = $this->settings['defaultCacheLifetime'];
-
-                // Save value in cache
-                $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
-            }
-            return $entry;
-        } else {
-            if (($entry = $this->cache->get($cacheIdentifier)) === false) {
-                $realties = $this->immobilieRepository->findAllWithFilter($filterToUse);
-
-                if ($this->settings['preset']['search']['useSlider'] == 1) {
-                    // BEGIN: Assign Values for Slider-Configuration to View
-                    $this->view->assign('sizeSliderData', $this->getSizeSliderData());
-                    $this->view->assign('roomSliderData', $this->getRoomSliderData());
-                    $this->view->assign('amountSliderData', $this->getAmountSliderData());
-                    // END: Assign Values for Slider-Configuration to View
+                // add city to this filte
+                $ort = $this->filter->getOrt();
+                if ($ort instanceof Ort) {
+                    $filter->addOrt($ort);
+                }
+                if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+                    $filter->setImportIds($this->filter->getImportIds());
                 }
-                $this->view->assign('realties', $realties);
-                $this->view->assign('instantFilter', $this->generateInstantFilterPresetsFromResult($realties));
-                $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
-                $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
-                $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
-                $this->view->assign('filter', $this->filter);
-                $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
-                $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
 
-                $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
+                $filterToUse = $filter;
+                $cacheIdentifier = 'list_' . $this->filter->getCacheIdentifier() . '_L' . $this->getLanguageUid();
+            } else {
+                $filterToUse = $this->filter;
+                $cacheIdentifier = 'list_' . $filterToUse->getCacheIdentifier() . '_L' . $this->getLanguageUid();
+            }
 
-                $entry = $this->view->render();
+            if ($this->noSearchParameters && $this->settings['list']['noParametersNoResults'] !== '0') {
+                if (($entry = $this->cache->get('sg_estate_base_empty_result' . '_L' . $this->getLanguageUid())) === false) {
+                    $this->view->assign('realties', []);
+                    $this->view->assign('aggregatedFilterData', json_encode([]));
+                    $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
 
-                $tags = ['listing', 'searchresult'];
-                $lifetime = $this->settings['defaultCacheLifetime'];
+                    $this->view->assign('presets', $this->generateFilterPresetsFromResult([]));
 
-                // Save value in cache
-                $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
+                    $entry = $this->view->render();
+
+                    $tags = ['listing', 'searchresult'];
+                    $lifetime = $this->settings['defaultCacheLifetime'];
+
+                    // Save value in cache
+                    $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
+                }
+                return $entry;
+            } else {
+                if (($entry = $this->cache->get($cacheIdentifier)) === false) {
+                    $realties = $this->immobilieRepository->findAllWithFilter($filterToUse);
+
+                    // Sorting data by current city
+                    if ($this->settings['preset']['search']['sortByCurrentCity'] == 1) {
+                        $cityName = explode(',', $filterToUse->getAddressString());
+                        $sortingData1 = [];
+                        $sortingData2 = [];
+                        foreach ($realties as $key => $realty) {
+                            if ($cityName[0] == $realty->getObjektOrt()->getBezeichner()) {
+                                $sortingData1[$key] = $realty;
+                            } else {
+                                $sortingData2[$key] = $realty;
+                            }
+                        }
+                        $realties = array_merge($sortingData1, $sortingData2);
+                    }
+
+                    if ($this->settings['preset']['search']['swoppenExt'] == 1 && count($realties) > 0) {
+                        $lastimportRepository = $this->objectManager->get('SG\SgEstateImportSwoppen\Domain\Repository\LastimportRepository');
+                        $lastImport = $lastimportRepository->findLastTstempByImportId(array($realties[0]->getImportNumber()));
+                        $this->view->assign('lastImport', $lastImport);
+                    }
+
+                    if ($this->settings['preset']['search']['useSlider'] == 1) {
+                        // BEGIN: Assign Values for Slider-Configuration to View
+                        $this->view->assign('sizeSliderData', $this->getSizeSliderData());
+                        $this->view->assign('roomSliderData', $this->getRoomSliderData());
+                        $this->view->assign('amountSliderData', $this->getAmountSliderData());
+                        // END: Assign Values for Slider-Configuration to View
+                    }
+                    $this->view->assign('realties', $realties);
+                    $this->view->assign('instantFilter', $this->generateInstantFilterPresetsFromResult($realties));
+                    $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
+                    $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
+                    $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+                    $this->view->assign('filter', $this->filter);
+                    $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
+                    $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
+
+                    $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
+
+                    $entry = $this->view->render();
+
+                    $tags = ['listing', 'searchresult'];
+                    $lifetime = $this->settings['defaultCacheLifetime'];
+
+                    // Save value in cache
+                    $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
+                }
+                return $entry;
             }
-            return $entry;
-        }
     }
 
     /**
@@ -402,14 +462,33 @@ class BaseController extends ActionController
         $entry      = null;
         $noCache    = isset($this->settings['detail']['cache'])
             ? $this->settings['detail']['cache'] : 0;
+        
+        /**
+         * @var $filter Filter
+         */
+        if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+            $arrayOfImportIds = explode(',', $this->settings['importids']);
+            if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
+            } else {
+                $arrayOfImportIds = [];
+            }
+        }
+        else {
+            $arrayOfImportIds = [];
+        }
+        
         if(!empty($realty)) {
             if($noCache != 1) {
-                $cacheIdentifier = 'detail_' . sha1($realty) . '_L' . $this->getLanguageUid();
+                $cacheIdentifier = 'detail_' . sha1($realty.$this->settings['importids']) . '_L' . $this->getLanguageUid();
                 if(($entry = $this->cache->get($cacheIdentifier)) === false) {
-                    if((int) $realty > 0)
-                        $estateItem = $this->immobilieRepository->findByUid((int)$realty);
-                    if(!$estateItem instanceof Immobilie)
-                        $estateItem = $this->immobilieRepository->findOneByUrlIdentifier($realty);
+                    if ((int) $realty > 0) {
+                        $estateItem = $this->immobilieRepository->findByUid((int)$realty, $arrayOfImportIds);
+                    }
+
+                    if (!($estateItem instanceof Immobilie)) {
+                        $estateItem = $this->immobilieRepository->findOneByUrlIdentifier($realty, $arrayOfImportIds);
+                    }
+
                     $this->view->assign('realty', $estateItem);
                     $this->view->assign('filter', $this->filter);
                     $entry = $this->view->render();
@@ -419,9 +498,9 @@ class BaseController extends ActionController
                 }
             } else {
                 if((int) $realty > 0)
-                    $estateItem = $this->immobilieRepository->findByUid((int)$realty);
+                    $estateItem = $this->immobilieRepository->findByUid((int)$realty, $arrayOfImportIds);
                 if(!$estateItem instanceof Immobilie)
-                    $estateItem = $this->immobilieRepository->findOneByUrlIdentifier($realty);
+                    $estateItem = $this->immobilieRepository->findOneByUrlIdentifier($realty, $arrayOfImportIds);
                 $this->view->assign('realty', $estateItem);
                 $this->view->assign('filter', $this->filter);
                 $entry = $this->view->render();
@@ -480,7 +559,7 @@ class BaseController extends ActionController
         }
     }
 
-    private function generateCityAndDistrictStructureForFilter()
+    protected function generateCityAndDistrictStructureForFilter()
     {
         $cityAndDistrictStructure = [];
 
@@ -488,7 +567,7 @@ class BaseController extends ActionController
             /**
              * @var $city Ort
              */
-            $city_qtys = $city->getAnzahlImmobilienArray();
+            $city_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
             $city_qty = in_array('WOHNUNG', array_keys($city_qtys)) ? $city_qtys['WOHNUNG'] : 0;
             $newCity = [
                 'caption' => $city->getBezeichner(),
@@ -501,7 +580,7 @@ class BaseController extends ActionController
                     /**
                      * @var $district Stadtteil
                      */
-                    $district_qtys = $city->getAnzahlImmobilienArray();
+                    $district_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
                     $district_qty = in_array('WOHNUNG', array_keys($district_qtys)) ? $district_qtys['WOHNUNG'] : 0;
                     $newDistrict = [
                         'caption' => $district->getBezeichner(),
@@ -626,7 +705,7 @@ class BaseController extends ActionController
                             a.objekt_breitengrad AS lat,
                             a.objekt_laengengrad AS lng,
                             a.objekt_stadtteil AS district_id,
-                            b.bezeichner AS district_name,
+                            IFNULL(b.bezeichner, '') AS district_name,
                             c.kuerzel AS object_art,
                             a.objekt_ort AS city_id,
                             d.bezeichner AS city_name,
@@ -649,6 +728,7 @@ class BaseController extends ActionController
                             AND task_type = 'Image.CropScaleMask' 
                             AND width = " . $cw . "
                             AND height = " .$ch;
+                    
                     $connection = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionByName('Default');
                     $allRealties = $connection->createQueryBuilder()->addSelectLiteral($sql)->execute()->fetchAll();
                     $arrayReturn = ['realties' => []];
@@ -704,8 +784,6 @@ class BaseController extends ActionController
                     return $entry;
                     break;
 
-
-
                 case 'allRealties':
                     $cacheIdentifier = 'ajax_allRealties';
 
@@ -867,14 +945,14 @@ class BaseController extends ActionController
                         if ($realty instanceof Immobilie) {
                             $lat = $this->filter->getLatitude() > 0
                                 ? $this->filter->getLatitude()
-                                : $this->request->hasArgument('lat')
+                                : ($this->request->hasArgument('lat')
                                     ? $this->request->getArgument('lat')
-                                    : 0;
+                                    : 0);
                             $lon = $this->filter->getLongitude() > 0
                                 ? $this->filter->getLongitude()
-                                : $this->request->hasArgument('lon')
+                                : ($this->request->hasArgument('lon')
                                     ? $this->request->getArgument('lon')
-                                    : 0;
+                                    : 0);
                             $this->view->assign('distance', $this->calcDistance($realty->getObjektBreitengrad(), $realty->getObjektLaengengrad(), $lat, $lon));
                             //$this->view->assign('distance', $this->calcDistance($realty->getObjektBreitengrad(), $realty->getObjektLaengengrad(), $this->filter->getLatitude(), $this->filter->getLongitude()));
                         }
@@ -972,7 +1050,7 @@ class BaseController extends ActionController
      * Internal & Helper Functions
      *********************************************/
 
-    private function calcDistance($latitudePoint1, $longitudePoint1, $latitudePoint2, $longitudePoint2)
+    protected function calcDistance($latitudePoint1, $longitudePoint1, $latitudePoint2, $longitudePoint2)
     {
         $pi80 = M_PI / 180;
         $latitudePoint1 *= $pi80;
@@ -988,14 +1066,14 @@ class BaseController extends ActionController
         return $km;
     }
 
-    private function pregenerateContactForm()
+    protected function pregenerateContactForm()
     {
         ksort($this->settings['contact']['fields']);
         $this->view->assign('settings', $this->settings);
         $this->view->assign('salutationOptions', $this->getSalutationOptions());
     }
 
-    private function transformFieldConfiguration()
+    protected function transformFieldConfiguration()
     {
         $transformedConfiguration = [];
         foreach ($this->settings['contact']['fields'] as $fieldConfiguration) {
@@ -1009,7 +1087,7 @@ class BaseController extends ActionController
      * @throws StopActionException
      * @throws UnsupportedRequestTypeException
      */
-    private function processContactForm()
+    protected function processContactForm()
     {
         /**
          * @var $formValues array
@@ -1109,7 +1187,7 @@ class BaseController extends ActionController
      *
      * @return array
      */
-    private function getSalutationOptions()
+    protected function getSalutationOptions()
     {
         return [
             'mr' => LocalizationUtility::translate('template.contact.salutation.mr', 'sg_estate_base'),
@@ -1122,7 +1200,7 @@ class BaseController extends ActionController
      *
      * @throws NoSuchArgumentException
      */
-    private function setFilter()
+    protected function setFilter()
     {
         if ($this->request->hasArgument('filter')) {
             /**
@@ -1256,7 +1334,11 @@ class BaseController extends ActionController
             if (isset($filterValues['personsFrom']) && is_numeric($filterValues['personsFrom']) && $filterValues['personsFrom'] > 0) {
                 $this->filter->setPersonsFrom($filterValues['personsFrom']);
             } else {
-                $this->filter->setPersonsFrom(0);
+                if($this->settings['preset']['search']['persons'] > 0){
+                    $this->filter->setPersonsFrom($this->settings['preset']['search']['persons']);
+                }else{
+                    $this->filter->setPersonsFrom(0);
+                }
             }
             if (isset($filterValues['personsTo']) && is_numeric($filterValues['personsTo']) && $filterValues['personsTo'] > 0) {
                 $this->filter->setPersonsTo($filterValues['personsTo']);
@@ -1277,6 +1359,10 @@ class BaseController extends ActionController
                 } else {
                     $this->filter->setPersonsTo(0);
                 }
+            }else{
+                if($this->settings['preset']['search']['persons'] > 0){
+                    $this->filter->setPersonsString($this->settings['preset']['search']['persons']);
+                }
             }
         } else {
             // No Data for Filter in Request
@@ -1298,7 +1384,7 @@ class BaseController extends ActionController
      *
      * @return array
      */
-    private function getSizeSliderData()
+    protected function getSizeSliderData()
     {
         return [
             'range' => $this->settings['preset']['slider']['size']['range'],
@@ -1314,7 +1400,7 @@ class BaseController extends ActionController
      *
      * @return array
      */
-    private function getRoomSliderData()
+    protected function getRoomSliderData()
     {
         return [
             'range' => $this->settings['preset']['slider']['room']['range'],
@@ -1330,7 +1416,7 @@ class BaseController extends ActionController
      *
      * @return array
      */
-    private function getAmountSliderData()
+    protected function getAmountSliderData()
     {
         return [
             'range' => $this->settings['preset']['slider']['amount']['range'],
@@ -1344,7 +1430,7 @@ class BaseController extends ActionController
      * @param $result
      * @return array
      */
-    private function generateInstantFilterPresetsFromResult($result)
+    protected function generateInstantFilterPresetsFromResult($result)
     {
         $presets = [];
 
@@ -1433,7 +1519,7 @@ class BaseController extends ActionController
         return $presets;
     }
 
-    private function generateFeedbackAttachment($templateName, array $variables = [], $format = 'xml')
+    protected function generateFeedbackAttachment($templateName, array $variables = [], $format = 'xml')
     {
         /**
          * @var $standaloneView StandaloneView
@@ -1469,7 +1555,7 @@ class BaseController extends ActionController
      * @param string $format
      * @return bool
      */
-    private function sendTemplateEmail(array $recipients = [], array $bcc = [], $sender, $subject, $templateName, array $variables = [], $format = 'text/plain', $attachments = [])
+    protected function sendTemplateEmail(array $recipients = [], array $bcc = [], $sender, $subject, $templateName, array $variables = [], $format = 'text/plain', $attachments = [])
     {
         /**
          * @var $emailView StandaloneView
@@ -1539,7 +1625,7 @@ class BaseController extends ActionController
     /**
      * Get the current language
      */
-    private function getLanguageUid()
+    protected function getLanguageUid()
     {
         $context = GeneralUtility::makeInstance(Context::class);
         $sysLanguageUid = $context->getPropertyFromAspect('language', 'id');
@@ -1550,7 +1636,7 @@ class BaseController extends ActionController
         }
     }
 
-    private function getAggregatedFilterData()
+    protected function getAggregatedFilterData()
     {
         return [
             'size' => !$this->filter->getFlaecheAb() ? $this->getSizeSliderData()['value'] : $this->filter->getFlaecheAb(),
@@ -1564,7 +1650,7 @@ class BaseController extends ActionController
      * in ascending order (bezeichner field)
      * @param  array &$districts Array to sort
      */
-    private function sortDistrictsPresetArray( &$districts )
+    protected function sortDistrictsPresetArray( &$districts )
     {
         $sorted = false;
         $districtsCount = count( $districts )-1;
@@ -1593,7 +1679,7 @@ class BaseController extends ActionController
      * @param $result
      * @return array
      */
-    private function generateFilterPresetsFromResult($result){
+    protected function generateFilterPresetsFromResult($result){
         $presets = array();
 
         // Initialize
@@ -1704,4 +1790,10 @@ class BaseController extends ActionController
         return $presets;
     }
 
+    public function presetsAction() {
+        $this->view->assign('cities', $this->ortRepository->findAll());
+        $entry = $this->view->render();
+        return $entry;
+    }
+
 }
